#!/usr/local/bin/perl

use strict;
use MyBench;
use Getopt::Long;
use Time::HiRes qw(gettimeofday tv_interval);
use DBI;

my $num = $ARGV[0] || 10_000;
my $num_kids = 5; # プロセス数
my $num_runs = 100; # 繰り返し回数

my $table = join '_', 'entry', $num;
my $blogs_num = int($num / 50);

my $callback = sub {
    my $id  = shift;
    my $dbh = DBI->connect('dbi:mysql:webdb;hostname=db-host', 'root', '', { RaiseError => 1 });
    my $sth = $dbh->prepare("SELECT * FROM $table WHERE blog_id = ?");

    my $cnt = 0;
    my @times = ();

    # 親プロセスが HUP シグナルを送ってくるまで待機
    local $SIG{HUP} = sub { };
    sleep 600;

    while ($cnt < $num_runs) {
        my $v = int(rand($blogs_num));
        my $t0 = [gettimeofday];
        $sth->execute($v);
        my $t1 = tv_interval($t0, [gettimeofday]);
        push @times, $t1;
        $sth->finish();
        $cnt++;
    }

    $dbh->disconnect();
    my @r = ($id, scalar(@times), min(@times), max(@times), avg(@times), tot(@times));
    return @r;
};

my @results = MyBench::fork_and_work($num_kids, $callback);
MyBench::compute_results('test', @results);

exit;

